@@ -1,5 +1,5 @@
+#compute composite loss function cfun(z), where z is the value computed from convex function dfun
 compute_g <- function(z, cfun, s, delta=0.0001){
-    if(any(z < 0)) stop("z must be non-negative")
     if(is.null(s)) s <- assign_s(cfun, z) else check_s(cfun, s)
     if(cfun==6)
            if(s > 1) delta <- (s-1)/2 else
